plot_most_likely_terciles <- function(recipe,
                                      fcst,
                                      probabilities, 
                                      outdir) {

  ## TODO: Add 'anomaly' to plot title
  # Abort if frequency is daily
  if (recipe$Analysis$Variables$freq == "daily_mean") {
    stop("Visualization functions not yet implemented for daily data.")
  }

  latitude <- fcst$coords$lat
  longitude <- fcst$coords$lon
  archive <- get_archive(recipe)
  system_name <- archive$System[[recipe$Analysis$Datasets$System$name]]$name
  variable <- recipe$Analysis$Variables$name
  start_date <- paste0(recipe$Analysis$Time$fcst_year,
                       recipe$Analysis$Time$sdate)

  # Retrieve and rearrange probability bins for the forecast
  if (is.null(probabilities$probs_fcst$prob_b33) ||
      is.null(probabilities$probs_fcst$prob_33_to_66) ||
      is.null(probabilities$probs_fcst$prob_a66)) {
    stop("The forecast tercile probability bins are not present inside ",
         "'probabilities', the most likely tercile map cannot be plotted.")
  }

  probs_fcst <- abind(probabilities$probs_fcst$prob_b33,
                      probabilities$probs_fcst$prob_33_to_66,
                      probabilities$probs_fcst$prob_a66,
                      along = 0)
  names(dim(probs_fcst)) <- c("bin",
                              names(dim(probabilities$probs_fcst$prob_b33)))

  ## TODO: Improve this section
  # Drop extra dims, add time dim if missing:
  probs_fcst <- drop(probs_fcst)
  if (!("time" %in% names(dim(probs_fcst)))) {
    dim(probs_fcst) <- c("time" = 1, dim(probs_fcst))
  }
  if (!'syear' %in% names(dim(probs_fcst))) {
    probs_fcst <- Reorder(probs_fcst, c("time", "bin", "longitude", "latitude"))
  } else {
    probs_fcst <- Reorder(probs_fcst,
                          c("syear", "time", "bin", "longitude", "latitude"))
  }

  for (i_syear in start_date) {
    # Define name of output file and titles
    if (length(start_date) == 1) {
      i_probs_fcst <- probs_fcst
      outfile <- paste0(outdir, "forecast_most_likely_tercile-", start_date,
                        ".png")
    } else {
      i_probs_fcst <- probs_fcst[which(start_date == i_syear), , , , ]
      outfile <- paste0(outdir, "forecast_most_likely_tercile-", i_syear, ".png")
    }
    toptitle <- paste("Most Likely Tercile -", variable, "-", system_name, "-",
                      "Initialization:", i_syear)
    months <- lubridate::month(fcst$attrs$Dates[1, 1, which(start_date == i_syear), ],
                               label = T, abb = F)
    ## TODO: Ensure this works for daily and sub-daily cases
    titles <- as.vector(months)

    # Plots
    ## NOTE: PlotLayout() and PlotMostLikelyQuantileMap() are still being worked
    ## on. 
    suppressWarnings(
    PlotLayout(PlotMostLikelyQuantileMap, c('bin', 'longitude', 'latitude'),
               cat_dim = 'bin',
               i_probs_fcst, longitude, latitude,
               coast_width = 1.5,
               title_scale = 0.6,
               legend_scale = 0.8, #cex_bar_titles = 0.6,
               toptitle = toptitle,
               titles = titles,
               fileout = outfile,
               bar_label_digits = 2,
               bar_scale = rep(0.7, 4),
               bar_label_scale = 1.2,
               axes_label_scale = 1.3,
               triangle_ends = c(F, F), width = 11, height = 8)
    )
  }

  info(recipe$Run$logger,
       "##### MOST LIKELY TERCILE PLOT SAVED TO OUTPUT DIRECTORY #####")
}
